@@ -457,7 +457,7 @@ create_ekpnavi_dialog (void)
                       NULL);
 
   gtk_widget_grab_focus (ok_button);
-  /* gtk_widget_grab_default (ok_button);				    */
+  gtk_widget_grab_default (ok_button);
   /* gtk_window_add_accel_group (GTK_WINDOW (ekpnavi_dialog), accel_group); */
 
   return ekpnavi_dialog;
