@@ -19,9 +19,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <string.h>
@@ -34,10 +31,6 @@
 #include "ekpcom.h"
 #include "inkbox.h"
 #include "error.xpm"
-
-#if COVER_OPEN || CD_DVD_OPEN
-#include "error_i2.xpm"
-#endif
 #include "error_i3.xpm"
 #include "error_i4.xpm"
 #include "error_i6.xpm"
@@ -76,9 +69,6 @@ typedef enum
 	STS_ERR_CUT_MISS,
 	STS_ERR_OTHER_INK,
 	STS_ERR_COMBINATION,
-	STS_ERR_COPYING,	/* Added for Scanner-Pirinter-Copy  */
-	STS_ERR_COVER_OPEN,	/* Added for Scanner-Pirinter-Copy  */
-	STS_ERR_CD_DVD_OPEN,	/* Added for CD/DVD Tray Open	    */
 	STS_DEFAULT
 }PRINTER_STS;
 
@@ -108,22 +98,6 @@ typedef struct{
 
 static PRINTSTSSTRUCT _status_str;
 
-/* 2004.03.08		*/	
-/* ink color name 	*/
-static const char *ink_name[] = {
-  N_("NBlack"),
-  N_("Cyan"),
-  N_("Magenta"),
-  N_("Yellow"),
-  N_("Light Cyan"),
-  N_("Light Magenta"),
-  N_("Dark Yellow"),
-  N_("Photo Black"),
-  N_("Matte Black"),
-  N_("Red"),
-  N_("Blue"),
-  N_("Gloss Optimizer")
-};
 
 static PRINTER_STS ReadStatuslogfile (InkList *);
 static void SetAllUserButtonHidden (void);
@@ -169,7 +143,8 @@ ReadStatuslogfile (InkList *list)
 
 	/* 󥯼 */
 	lpInk = strstr (lpReply, "INK:");
-	if (lpInk){
+	if (lpInk)
+	{
 		char ic[7] = "0x";
 		InkNode *prev = NULL;
 
@@ -199,65 +174,6 @@ ReadStatuslogfile (InkList *list)
 			}
 			node = node->next;
 		}
-	}else{
-		char snink[3];
-		int  nink, i;
-		InkNode *prev = NULL;
-
-		/* 2004.03.18		*/
-		/* INK:... not reply 	*/
-		/* check "AI:CW:"	*/
-		lpInk = strstr (lpReply, "AI:CW:");
-		if( !lpInk )	
-			return STS_NO_REPLY;
-		/* Found!		*/	
-		lpInk += 6;	/* skip "AI:CW:" */
-
-		/* get no. of ink */
-		sprintf( snink, "%.2s", lpInk);
-		nink = atoi( snink );		
-		lpInk += 2;
-
-		/* setup ink list */
-		for( i = 0; i < nink ; i++ ){
-			InkNode *node;
-
-			node = (InkNode *)calloc(1, sizeof(InkNode));
-			if (!node) {
-				return STS_NO_REPLY;
-			}
-
-			switch( i ){
-			case	0: /* black */
-				node->id = 0x1101;break;	
-			case	1: /* cyan */
-				node->id = 0x3202;break;
-			case	2: /* yellow */
-				node->id = 0x4304;break;
-			case	3: /* magenta */
-				node->id = 0x5408;break;
-			case	4: /* light cyan */
-				node->id = 0x6210;break;
-			case	5: /* light magenta */
-				node->id = 0x7320;break;
-			case	6: /* dark yellow */
-				node->id = 0x9440;break;
-			case	7: /* light black */
-				node->id = 0x1140;break;
-			default	:
-				node->id = 0x0;break;
-			   break;
-			}
-			
-			if (prev) {
-				prev->next = node;
-				prev = prev->next;
-			} else {
-				prev = node;
-				*list = prev;
-			}
-			node = node->next;
-		}
 	}
 
 
@@ -304,10 +220,6 @@ ReadStatuslogfile (InkList *list)
 		if(!strcmp(StsCode, "00")){
 			/* 顼ơ */
 			lpErr = strstr(lpReply, "ER:");
-			
-#if DEBUG
-			fprintf(stderr, "error code = %s\n", lpErr);
-#endif
 			if(lpErr){
 				strncpy(ErrCode, lpErr + 3, 2);
 				if(!strcmp(ErrCode, "04")) return STS_ERR_JAM;
@@ -318,20 +230,7 @@ ReadStatuslogfile (InkList *list)
 				if(!strcmp(ErrCode, "12")) return STS_ERR_REPETITION;
 				/* added - Sat Feb 22 2003 */
 				if(!strcmp(ErrCode, "00")) return STS_ERR_FATAL;
-#if SPC_MODEL
-				if(!strcmp(ErrCode, "01")) return STS_ERR_COPYING;
-#else
 				if(!strcmp(ErrCode, "01")) return STS_ERR_OTHER_IF;
-#endif
-
-#if COVER_OPEN				
-				/* Added Status 2003.11.25	*/
-				if(!strcmp(ErrCode, "02")) return STS_ERR_COVER_OPEN;
-#elif CD_DVD_OPEN
-				/* Added Status 2004.01.08	*/
-				if(!strcmp(ErrCode, "02")) return STS_ERR_CD_DVD_OPEN;
-#endif	
-				
 				if(!strcmp(ErrCode, "03")) return STS_ERR_LEVER;
 				if(!strcmp(ErrCode, "0C")) return STS_ERR_TRAY;
 				if(!strcmp(ErrCode, "0D")) return STS_ERR_THICK_PAPER;
@@ -344,21 +243,12 @@ ReadStatuslogfile (InkList *list)
 			}
 			return STS_ERR_FATAL;
 		}
-#if DEBUG
-		/* Debug */
-		fprintf(stderr, "status code = %s\n", StsCode);
-#endif
-
 		if(!strcmp(StsCode, "01") || !strcmp(StsCode, "07")) return STS_NOT_READY;
 		if(!strcmp(StsCode, "03") || !strcmp(StsCode, "02")) return STS_PRINTING;
 		if(!strcmp(StsCode, "04")) return STS_IDLE;
 		if(!strcmp(StsCode, "09")) return STS_MOTOR_OFF; /* add sk     -Fri Mar  9 2001 */
 		if(!strcmp(StsCode, "CN")) return STS_PRINTER_RESET;
 	}
-
-	/* Debug */
-	// fprintf(stderr, "...No Reply\n", StsCode);
-	
 	return STS_NO_REPLY;
 }
 
@@ -521,7 +411,6 @@ GetPrinterStatus (gpointer data)
 								     (gchar**)error_i8);
 		gtk_label_set_text(GTK_LABEL(label), _("Paper jam"));
 		DisplayInformation(GTK_TEXT(txt), _("Press the Maintenance button on the printer or click the Eject button when it appears on the screen. Remove any remaining jammed paper by hand."));
-
 		SetAllUserButtonHidden();
 
 #ifndef NO_ACTION
@@ -696,10 +585,8 @@ GetPrinterStatus (gpointer data)
 						    "To cancel print jobs, click the Cancel button."));
 		SetAllUserButtonHidden();
 
-		/* 2004.03.02 close button -> cancel button */
-		widget = lookup_widget (_status_str.window, "cancel_button");
+		widget = lookup_widget (_status_str.window, "close_button");
 		gtk_widget_show(widget);
-		
 		break;
 
 	case STS_ERR_THICK_PAPER:
@@ -886,62 +773,6 @@ GetPrinterStatus (gpointer data)
 		gtk_widget_show(widget);
 		break;
 
-#if SPC_MODEL
-	/* Added new error message */
-	case STS_ERR_COPYING:
-		_status_str.num_pict = 2;
-		_status_str.pixmap[0] = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
-								     &_status_str.mask[0], NULL,
-								     (gchar**)ready);
-		_status_str.pixmap[1] = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
-								     &_status_str.mask[1], NULL,
-								     (gchar**)ready_i1);
-		gtk_label_set_text(GTK_LABEL(label), _("Copying"));
-		DisplayInformation(GTK_TEXT(txt), _("Please wait."));
-		SetAllUserButtonHidden();
-
-		widget = lookup_widget (_status_str.window, "close_button");
-		gtk_widget_show(widget);
-		break;
-#endif
-#if COVER_OPEN
-	/*  Added new error message */
-	case STS_ERR_COVER_OPEN:
-		_status_str.num_pict = 2;
-		_status_str.pixmap[0] = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
-								     &_status_str.mask[0], NULL,
-								     (gchar**)error);
-		_status_str.pixmap[1] = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
-								     &_status_str.mask[1], NULL,
-								     (gchar**)error_i2);
-		gtk_label_set_text(GTK_LABEL(label), _("Printer cover open"));
-		DisplayInformation(GTK_TEXT(txt), _("Close the printer cover."));
-		SetAllUserButtonHidden();
-
-		widget = lookup_widget (_status_str.window, "cancel_button");
-		gtk_widget_show(widget);
-		break;
-#endif
-#if CD_DVD_OPEN
-	/*  Added new error message */
-	case STS_ERR_CD_DVD_OPEN:
-		_status_str.num_pict = 2;
-		_status_str.pixmap[0] = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
-								     &_status_str.mask[0], NULL,
-								     (gchar**)error);
-		_status_str.pixmap[1] = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
-								     &_status_str.mask[1], NULL,
-								     (gchar**)error_i2);
-		gtk_label_set_text(GTK_LABEL(label), _("CD/DVD guide open"));
-		DisplayInformation(GTK_TEXT(txt), _("Remove the CD/DVD tray, then close the CD/DVD guide."));
-		SetAllUserButtonHidden();
-
-		widget = lookup_widget (_status_str.window, "cancel_button");
-		gtk_widget_show(widget);
-		break;
-#endif
-	
-
 	default:
 		_status_str.num_pict = 2;
 		_status_str.pixmap[0] = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
@@ -1083,10 +914,6 @@ setInkProg(InkList list)
 	int i;
 	char pix_name[] = "pixmap?";
 
-	/* 2004.03.08 for tooltips */
-	GtkTooltipsData *tips;
-	GtkWidget *event;
-	char event_name[] = "eventbox?";
 
 	while (node) {
 		if (node->rest < 0 || node->rest > 100) {
@@ -1112,8 +939,7 @@ setInkProg(InkList list)
 		
 		pix_name[6] = '1' + _status_str.inkbox_counter;
 		pix = lookup_widget (_status_str.window, pix_name);
-
-
+		
 		inkbox_chenge_volume (_status_str.inkbox_xpm, node->id, node->rest);
 		inkbox_pixmap = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
 							     &inkbox_mask, NULL,
@@ -1125,11 +951,6 @@ setInkProg(InkList list)
 		gdk_pixmap_unref (inkbox_pixmap);
 		gdk_bitmap_unref (inkbox_mask);
 		
-		/* 2004.03.08 for tooltips */
-		event_name[8] = '1' + _status_str.inkbox_counter;
-		event = lookup_widget (_status_str.window, event_name);
-		gtk_widget_show ( event );
-		
 		_status_str.inkbox_use_flag[_status_str.inkbox_counter] = 1;
 		_status_str.inkbox_counter++;
 	}
@@ -1139,14 +960,9 @@ setInkProg(InkList list)
 		{
 			pix_name[6] = '1' + i;
 			pix = lookup_widget (_status_str.window, pix_name);
-
-			/* 2004.03.08 for tooltips */
-			event_name[8] = '1' + i;
-			event = lookup_widget (_status_str.window, event_name);
 			
 			if (node != NULL && (node->rest >= 0 && node->rest <= 100))
 			{
-
 				inkbox_chenge_volume (_status_str.inkbox_xpm, node->id, node->rest);
 				inkbox_pixmap = gdk_pixmap_create_from_xpm_d(_status_str.window->window,
 									     &inkbox_mask, NULL,
@@ -1158,22 +974,11 @@ setInkProg(InkList list)
 				gtk_widget_show (pix);
 				gdk_pixmap_unref (inkbox_pixmap);
 				gdk_bitmap_unref (inkbox_mask);
-
-				/* 2004.03.08		    */
-				/* set tooltips label again */
-				tips = gtk_tooltips_data_get( event );
-				if( tips ){
-					gtk_tooltips_set_tip( tips->tooltips, tips->widget,
-						       (char*)_(ink_name[ inkbox_get_inkid(node->id) ]), NULL );	
-				}
-				gtk_widget_show ( event );
-				
 				node = node->next;
 			}
 			else
 			{
 				_status_str.inkbox_use_flag[i] = 0;
-				gtk_widget_hide ( event );
 				gtk_widget_hide (pix);
 			}
 		}
