@@ -23,11 +23,11 @@ if test -z $DESTDIR; then
     DESTDIR=
 fi
 
-PRINTER_MODEL_LOW=spr800
+PRINTER_MODEL_LOW=sp2100_2200
 PRINTER_MODEL=$(echo $PRINTER_MODEL_LOW | tr [:lower:] [:upper:])
 
-PIPS_BIN_NAME=pips-spr800
-PIPS_FILTER_NAME=filter-spr800
+PIPS_BIN_NAME=pips-sp2100_2200
+PIPS_FILTER_NAME=filter-sp2100_2200
 
 RM="rm -f"
 
