@@ -57,9 +57,9 @@ const char *outputLabels[] = {
   N_("to file"),
   NULL,
 };
-
+  
 const char *outputTypeLabels = N_("export file");
-
+  
 const char *finishButtonLabels[] = {
   N_("Save"),
   N_("Print"),
@@ -68,17 +68,17 @@ const char *finishButtonLabels[] = {
 };
 
 const char *def_margin_label = N_("Default");
-
+  
 OPTION_DATA inkData[] = {
   {     PIPS_OUTPUT_CMYKcm,     "COLOR",        N_("Color")        },
   {     PIPS_OUTPUT_MONO,       "MONO",         N_("Black")        },
   {     END_ARRAY,              "",             ""             }
 };
-
+  
 OPTION_DATA mediaSizeData[] = {
     { PIPS_PAPER_A4,            "A4",       N_("A4  210x297 mm")                    },
-    { PIPS_PAPER_A5,            "A5",       N_("A5  148x210 mm")                    },
-    { PIPS_PAPER_A6_INDEX,      "A6",       N_("A6  Index card 105x148 mm")         },
+    { PIPS_PAPER_A5,            "A5",       N_("A5 148x210 mm")                     },
+    { PIPS_PAPER_A6_INDEX,      "A6",       N_("A6  105x148 mm")                    },
     { PIPS_PAPER_B5,            "B5",       N_("B5  182x257 mm")                    },
     { PIPS_PAPER_LEGAL,         "LGL",      N_("Legal  8 1/2x14 in")                },
     { PIPS_PAPER_LETTER,        "LT",       N_("Letter  8 1/2x11 in")               },
@@ -92,26 +92,10 @@ OPTION_DATA mediaSizeData[] = {
     { PIPS_PAPER_JENV_YOU3,     "ENVY3",    N_("Envelope  98x148 mm")               },
     { PIPS_PAPER_JENV_YOU4,     "ENVY4",    N_("Envelope  105x235 mm")              },
     { PIPS_PAPER_TRIM_4X6,      "4X6",      N_("4x6 100x152 mm")                    },
-#if SPR300_310 || SPR200_210 || SPRX600_610 || SPRX500_510 || SPR800
-    { PIPS_PAPER_TRIM_L,        "L",        N_("3.5x5 in (9x13 cm)")                },
-#else
     { PIPS_PAPER_TRIM_L,        "L",        N_("3.5x5 in  89x127 mm")               },
-#endif
-#if SPR800
-    { PIPS_PAPER_TRIM_NAMECARD, "NC",       N_("Business Card 89x50 mm")            },
-#else
     { PIPS_PAPER_TRIM_NAMECARD, "NC",       N_("Business Card 89x55 mm")            },
-#endif
-#if SPR300_310 || SPR200_210 || SPRX600_610 || SPRX500_510 || SPR800
-    { PIPS_PAPER_TRIM_2L,        "2L",      N_("5x7 in (13x18 cm)")                  },
-#else
     { PIPS_PAPER_TRIM_2L,        "2L",      N_("5x7 in  127x178 mm")                },
-#endif
-#if SPR800
-	{ PIPS_PAPER_TRIM_LL,        "LL",      N_("3.5x5 in(Landscape)  13x9 cm")      },
-#else
     { PIPS_PAPER_TRIM_LL,        "LL",      N_("3.5x5 in(Landscape)  127x89 mm")    },
-#endif
     { PIPS_PAPER_A3,            "A3",       N_("A3  297x420 mm")                    },
     { PIPS_PAPER_A3_PLUS,       "A3+",      N_("Super A3 / B  329x483 mm")          },
     { PIPS_PAPER_B4,            "B4",       N_("B4  257x364 mm")                    },
@@ -119,31 +103,14 @@ OPTION_DATA mediaSizeData[] = {
     { PIPS_PAPER_HALF_LETTER,   "HLT",      N_("Half Letter  5 1/2x8 1/2 in")       },
     { PIPS_PAPER_INDEXCARD5,    "INDEX5",   N_("Index card  5x8 in")                },
     { PIPS_PAPER_INDEXCARD8,    "INDEX8",   N_("Index card  8x10 in")               },
-    { PIPS_PAPER_ENV_10,        "ENV10",    N_("Envelope #10  4 1/8x9 1/2 in")      },
+    { PIPS_PAPER_ENV_10,        "ENV10",    N_("Envelope #10  4 1/8x9 1/2")         },
     { PIPS_PAPER_ENV_DL,        "ENVDL",    N_("Envelope DL  110x220 mm")           },
     { PIPS_PAPER_ENV_C6,        "ENVC6",    N_("Envelope C6  114x162 mm")           },
     { PIPS_PAPER_ENV_FOR5X8,    "ENV5X8",   N_("Envelope 132x220 mm")               },
-#if SPR300_310 || SPR200_210 || SPRX600_610 || SPRX500_510 || SCX6300_6400S || SPR800 \
- || SC65_66S   || SC85_86S
-    { PIPS_PAPER_PHOTO_100x150, "PP100",    N_("10x15 cm Photo")                    },
-    { PIPS_PAPER_PHOTO_200x300, "PP200",    N_("20x30 cm Photo")                    },
-#else
     { PIPS_PAPER_PHOTO_100x150, "PP100",    N_("Photo Paper 100x150 mm")            },
     { PIPS_PAPER_PHOTO_200x300, "PP200",    N_("Photo Paper 200x300 mm")            },
-#endif
-    { PIPS_PAPER_4X6FULL,       "4X6FULL",  N_("Photo Paper 4x6 in  No Perforations")},
+    { PIPS_PAPER_4X6FULL,       "4X6FULL",  N_("4x6 in  No Perforations")           },
     { PIPS_PAPER_PANORAMIC,     "PANORAM",  N_("Panoramic 210x594 mm")              },
-
-    { PIPS_PAPER_BUSINESS_CARD,  "NC91",  N_("Business Card 55x91 mm")              },
-    { PIPS_PAPER_CREDITCARD,     "CARD",  N_("Card 54x86 mm")                       },
-    /* 2003/11/11 Added */
-/*     { PIPS_PAPER_P_ALBUM_A5_C,   "PAA5",  N_("Photo Album A5 Cover 210x303 mm")     }, */
-/*     { PIPS_PAPER_P_ALBUM_L_C,    "PAL",   N_("Photo Album L Size Cover 127x184 mm") }, */
-/*     { PIPS_PAPER_P_ALBUM_A4,     "PAA4",  N_("Photo Album A4 210x303 mm")           }, */
-/*     { PIPS_PAPER_P_ALBUM_A5_L,   "PAA5L", N_("Photo Album A5(Landscape 210x148 mm") }, */
-/*     { PIPS_PAPER_P_ALBUM_L_L,    "PALL",  N_("Photo Album L Size(Landscape) 127x89 mm") }, */
-/*     { PIPS_PAPER_P_ALBUM_2L,     "PA2L",  N_("Photo Album 2L Size 127x178 mm")      }, */
-
     { END_ARRAY,                "",         ""                                      }
 };
 
@@ -187,45 +154,18 @@ OPTION_DATA mediaTypeData[] = {
   {     PIPS_MED_PHOTOWEIGHT,   "PHOTOW",   N_("Glossy Paper-Photo Weight")         },
  /* 2003.05.23 Added */
   {     PIPS_MED_GLOSSYPHOTOPAPER,  "GPPAPER",  N_("Glossy Photo Paper")            },
-  {     PIPS_MED_RCPC, 	  	    "RCPC",     N_("Recycled Paper Postcard")       },
+  {     PIPS_MED_RCPC, 	  	    "RCPC",     N_("Recycled Postcard")   	    },
   {     PIPS_MED_MCLP,         "MCLP",          N_("Premium Luster Photo Paper")    },
   {     PIPS_MED_WATERCOLOR,   "WATERCOLOR", N_("Watercolor Paper - Radiant White") },
   /* 2003.09.02 Added */
   {     PIPS_MED_ERC,          "ERC",       N_("EPSON Photo Paper") },
-  {     PIPS_MED_EPM,	       "EPM",	N_("EPSON Photo Matte") }, 
-  {     PIPS_MED_EDMP,	       "EDMP",	N_("EPSON Double-Side Matte Paper ") }, 
-  {     PIPS_MED_EPS,	       "EPS",	N_("EPSON Photo Seal") }, 
-  {     PIPS_MED_EIRON_PRINT,  "EIRON",	N_("EPSON Iron Print Paper") }, 
-  /* 2003.10.23 Added */
-  {     PIPS_MED_EPP_P,        "EPP_P",	N_("DURABrite Photo Paper") },
-  {     PIPS_MED_BWP,          "BWP", 	N_("Bright White Paper") }, 
-  /* 2003.10.31 Added */
-  {     PIPS_MED_EGPP,         "EGPP",  N_("EPSON Glossy Photo Paper Pigment")},
-  {     PIPS_MED_RPPC,         "RPPC",  N_("Recycled Paper Postcard")},
-  {     PIPS_MED_ERC_S,        "ERC_S", N_("EPSON RC Photo Paper Silk Texture")},
-  /* 2003.11.11 Added */ 
-  {     PIPS_MED_EOHP,         "EOHP",  N_("EPSON Ink Jet Transparencies")},
-/*   {     PIPS_MED_P_ALBUM,      "P_ALBUM",N_("Photo Album Paper")}, */
-  {     PIPS_MED_P_BOARD,      "P_BOARD",N_("Photo Board Paper")},
- 
-  /* 2004.01.07 Added */
-  {     PIPS_MED_ADDRESSSIDE,  "ADDRESS",N_("Post Card Address Side")},
-  {     PIPS_MED_SF_POSTCARD,  "SFPC",   N_("Super Fine Post Card")},
 
 #if	(PM940C) || (PM980C)
-  // silent mask 
   {     PIPS_MED_PLAIN|SILENT_MASK, "PLAIN_SILENT",    N_("Plain Paper (Silent Feed)")   },
   {     PIPS_MED_EPP|SILENT_MASK,   "EPP_SILENT",      N_("EPSON Glossy Paper (Silent Feed)") },
 #endif
-  // new media type for only one mode.
-  {     PIPS_MED_PLAIN_SPEED, "PLAIN_SPEED",    N_("Plain Paper (Fast)")   },
-
-  // 2004.03.31
-  // new media type for "Black Ink Save"
-  {     PIPS_MED_PLAIN_BKSAVE, "PLAIN_BKSAVE",    N_("Plain Paper (Black Ink Save Mode)")   },
-
-  {     END_ARRAY,             "",         ""                       }
-
+  
+  {     END_ARRAY,              "",         ""                                      }
 };
 
 OPTION_DATA microWeaveData[] = {
@@ -260,42 +200,28 @@ OPTION_DATA binData[] = {
   {     PIPS_BIN_USER,          "ROLL",     N_("Roll Paper")                 },
   {     PIPS_BIN_TRIMBANNER,    "TROLL",    N_("Roll Paper (Banner)")        },
   {     PIPS_BIN_AUTO_TRIM,     "TAUTO",    N_("Sheet Feeder (Banner)")      },
-  {     PIPS_BIN_AUTO_TRIM_4,   "T4AUTO",   N_("Sheet Feeder-No Margins")    },
+  {     PIPS_BIN_AUTO_TRIM_4,   "T4AUTO",   N_("Sheet Feeder-No Margins"),   },
   {     PIPS_BIN_AUTO_EX,       "EXAUTO",   N_("Sheet Feeder-Area Maximum")  },
-/*   {     PIPS_BIN_ALBUM,         "ALBUM",    N_("Photo Album")                }, */
-/*   {     PIPS_BIN_ALBUM_TRIM,    "TALBUM",   N_("Photo Album-No Margins")     }, */
-  {     PIPS_BIN_MANUAL,        "MANUAL",   N_("Manual")                     },
-  {     PIPS_BIN_MANUAL_TRIM,   "TMANUAL",  N_("Manual-No Margins")          },       
   {     END_ARRAY,              "",         ""                               }
     
 };
 
 OPTION_DATA levelData[] = {
-#if (HIGH_RESOLUTION == 0) 
+#if (!HIGH_RESOLUTION) 
   {     PIPS_LV_DRAFT,          "DRAFT",        N_("Draft")           },
   {     PIPS_LV_STD,            "STD",          N_("Standard")        },
   {     PIPS_LV_FINE,           "FINE",         N_("Fine")            },
   {     PIPS_LV_SFINE,          "SFINE",        N_("Super Fine")      },
   {     PIPS_LV_PHOTO,          "PHOTO",        N_("Photo")           },
   {     PIPS_LV_SPHOTO,         "SPHOTO",       N_("Super Photo")     },
-#elif (HIGH_RESOLUTION == 1) 
-  /* High Resolution Pattern 1 */
-  {     PIPS_LV_DRAFT,          "DRAFT",        N_("Draft")           },
-  {     PIPS_LV_STD360,         "STD360",       N_("Standard (360dpi)")   },
-  {     PIPS_LV_FINE720,        "FINE720",      N_("Fine (720dpi)")       },
-  {     PIPS_LV_SFINE720,       "SFINE720",     N_("Super Fine (720dpi)") },
-  {     PIPS_LV_PHOTO1440,      "PHOTO1440",    N_("Photo (1440dpi)")     },
-  {     PIPS_LV_PHOTO2880,      "PHOTO2880",    N_("Photo (2880dpi)")     },
-  {     PIPS_LV_SPHOTO2880,     "SPHOTO2880",   N_("Super Photo (2880dpi)") },
 #else
-  /* High Resolution Pattern 2 */
+  /*  */
   {     PIPS_LV_DRAFT,          "DRAFT",        N_("Draft")           },
-  {     PIPS_LV_STD360,         "STD360",       N_("Standard (360dpi)")  },
-  {     PIPS_LV_FINE720,        "FINE720",      N_("Fine (720dpi)")       },
+  {     PIPS_LV_STD360,         "STD360",       N_("STD  (360dpi)")        },
+  {     PIPS_LV_FINE720,        "FINE720",      N_("Fine (720dpi)")        },
   {     PIPS_LV_SFINE720,       "SFINE720",     N_("Super Fine (720dpi)") },
   {     PIPS_LV_PHOTO1440,      "PHOTO1440",    N_("Photo (1440dpi)")     },
   {     PIPS_LV_PHOTO2880,      "PHOTO2880",    N_("Photo (2880dpi)")     },
-  {     PIPS_LV_SPHOTO1440,     "SPHOTO1440",   N_("Super Photo (1440dpi)") },
   {     PIPS_LV_SPHOTO2880,     "SPHOTO2880",   N_("Super Photo (2880dpi)") },
 #endif
 
@@ -325,8 +251,6 @@ OPTION_DATA inksetData[] = {
   {     PIPS_INKSET_CMYKcmLk,   "CMYKcmLk",       ""        },
   {     PIPS_INKSET_CMYcmMkLk,  "CMYcmMkLk",      ""        },
   {     PIPS_INKSET_CMYcmMk,    "CMYcmMk",        ""        },
-  {     PIPS_INKSET_CMYKRVCl,   "CMYKRVCl",       ""        },	/* 2004.01.22 New Inkset */
-  {     PIPS_INKSET_CMYKRV,     "CMYKRV",         ""        },	/* 2004.01.22 New Inkset */
   {     END_ARRAY,              "",        ""            }
 };
 
@@ -337,16 +261,6 @@ OPTION_DATA autoCutData[] = {
   {     END_ARRAY,      "",     ""                  }
 };
 
-/* ץƥޥбȼäɲ */
-/* 2004.01.07 Added */
-OPTION_DATA clearInkData[] = {
-  {     PIPS_CI_ON,          "ON",        N_("ON")      },
-  {     PIPS_CI_OFF,         "OFF",       N_("OFF")     },
-  {     PIPS_CI_AUTO,        "AUTO",      N_("ON(AUTO)")     },
-  {     PIPS_CI_FULL,        "FULL",      N_("ON(FULL)")     },
-  {     END_ARRAY,      "",     ""                  }
-};
-
 OPTION_ALL opt_all[] = {
   {     P_SCALE,                NULL,           N_("Reduce/Enlarge (%)")    },
   {     P_INK,                  inkData,        N_("Ink")                   },
@@ -367,7 +281,6 @@ OPTION_ALL opt_all[] = {
   {     P_MULTI_PAGE,           multiPageData,  N_("Multi Page")            },
   {     P_BIN,                  binData,        N_("Paper Source")          },
   {     P_AUTO_CUT,             autoCutData,    N_("Auto Cut")              },
-  {     P_CLEAR_INK,            clearInkData,   N_("Gloss Optimizer")       },
   {     P_STRENGTH_CYAN,        NULL,           N_("Cyan")                  },
   {     P_STRENGTH_MAGENTA,     NULL,           N_("Magenta")               },
   {     P_STRENGTH_YELLOW,      NULL,           N_("Yellow")                },
