@@ -73,7 +73,6 @@ const char *opts[] = {
 	"mp", "multipage",       /* id = 16 -not use option */
 	"ps", "papersource",     /* id = 17 */
 	"ac", "autocut",         /* id = 18 */
-	"ci", "clearink",        /* id = 19 2004.01.20 for PX-G900 */
 	NULL
 };
 
@@ -418,14 +417,7 @@ saveRsc (void *save_options[])
 
 	for (i = 0; i < N_OPT; i++)
 	{
-#if CLEAR_INK || AUTO_CUT
 		fprintf (fp, "%s = ", opts[i * 2 + 1]);
-#else
-		if(( i != P_CLEAR_INK ) && (i != P_AUTO_CUT )){
-			/* not write clear ink/auto cut option */
-			fprintf (fp, "%s = ", opts[i * 2 + 1]);
-		}
-#endif
 		switch (i)
 		{
 		case P_SCALE:
@@ -444,10 +436,7 @@ saveRsc (void *save_options[])
 		case P_QUALITY_LEVEL:
 		case P_BIN:
 		case P_MULTI_PAGE:
-#if CLEAR_INK || AUTO_CUT
 		case P_AUTO_CUT:
-		case P_CLEAR_INK: /* 2004.01.21 */
-#endif
 			fprintf (fp, "%s\n", (char*)save_options[i]);
 			break;
 
@@ -538,18 +527,6 @@ getOpts (int nargc, char **nargv, char **filename,
 				size = strlen (opts[opt_id * 2]);
 				if (!strncmp (nargv[arg_count] + 1, opts[opt_id * 2], size))
 				{
-#if !CLEAR_INK 
-					if( opt_id == P_CLEAR_INK ){
-						/* not support */				
-						return pipsError (error_data, OPTION_VALUES_ERROR);
-					}
-#endif
-#if !AUTO_CUT 
-					if( opt_id == P_AUTO_CUT ){
-						/* not support */				
-						return pipsError (error_data, OPTION_VALUES_ERROR);
-					}
-#endif
 					if (opt_id == P_STRENGTH) ni = 3;
 					else if (opt_id == P_MARGIN) ni = 2;
 					else ni = 1;
@@ -673,7 +650,6 @@ getOptsForX (void *options[], SEP_INIT_PARAM *sepip)
 		case P_MICRO_WEAVE:
 		case P_HIGH_SPEED:
 		case P_FIT_PAGE:
-		case P_CLEAR_INK: /* 2004.01.21 */
 			if(options[i] != NULL)
 				strcpy (sub_arg[0], (char *)options[i]);
 			else
@@ -740,14 +716,6 @@ checkConf (SEP_INIT_PARAM *sepip)
 			case PIPS_BIN_AUTO_TRIM_4:
 				msizeEntry = mediaSizeEntry_NMA; break;
 #endif /* USE_AUTO_TRIM_4 */
-
-#if PMG800 || PXG900
-			case PIPS_BIN_MANUAL:
-				msizeEntry = mediaSizeEntry_M; break;
-			case PIPS_BIN_MANUAL_TRIM:
-				msizeEntry = mediaSizeEntry_TM; break;
-#endif
-
 			default: return 1;
 	
 			}
@@ -880,15 +848,6 @@ printModeCheck (const short *mode, int count, SEP_INIT_PARAM *sepip)
 	   && mode[ofs + MOFS_HIGH_SPEED] != sepip->high_speed) {
 		return 1;
 	}
-	
-#if CLEAR_INK
-	/* 2004.01.21 for Clear Ink */
-	if(sepip->clear_ink >= 1
-	   && !(mode[ofs + MOFS_CLEAR_INK] & sepip->clear_ink) ) {
-		return 1;
-	}
-#endif
-
 	return 0;
 }
 
@@ -987,9 +946,6 @@ setConf (int id, SEP_INIT_PARAM *sepip,
 	case P_AUTO_CUT:
 		sepip->auto_cut = getValueOfDatabases (id, sub[0]); break;
 
-	case P_CLEAR_INK: /* 2004.01.21 */
-		sepip->clear_ink = getValueOfDatabases (id, sub[0]); break;
-		
 #ifdef CONV_VERSION2
 	case P_MARGIN:
 		sepip->margin.x = atoi (sub[0]);
@@ -1029,16 +985,14 @@ defSet (SEP_INIT_PARAM *sepip)
 	sepip->src_resolution.x = 360;
 	sepip->src_resolution.y = 360;
 	sepip->media_type = PIPS_MED_PLAIN;
-#if (SC81S) || (PXV700) || (PM970C) || (PM980C) || (SCX5100_5200S) \
-||  (SC64_63S) || (PMG800) || (CC600PX) || (SC84_83S) || (PXG900) || (SCX5300_5400S) \
-||  (SCX6300_6400S) || (SPR800) || (SC65_66S) || (SC85_86S)
+#if (SC81S) || (PXV700) || (PM970C) || (PM980C)
 	sepip->mw_type = PIPS_MW_OFF;
 #else
 	sepip->mw_type = PIPS_MW_ON;
 #endif
 	sepip->high_speed = PIPS_HS_ON;
 	sepip->color_correction = PIPS_CMM_PHOTO;
-#if (PM770C) || (PM3000C) || (PMG800) || (PXG900) || (SPR800)
+#if (PM770C) || (PM3000C)
 	sepip->halftone_type = PIPS_HT_SPEED;
 #else
 	sepip->halftone_type = PIPS_HT_QUALITY;
@@ -1052,12 +1006,8 @@ defSet (SEP_INIT_PARAM *sepip)
 	sepip->bin_id = PIPS_BIN_AUTO;
 #if (PM940C) || (PM980C) || (PM970C)
 	sepip->qlevel = PIPS_LV_FINE720;
-#elif (SC64_63S) || (PMG800) || (SC84_83S) || (PXG900) || (SCX5300_5400S) || (SPR300_310) \
-	|| (SPR200_210) || (SPRX600_610) || (SPRX500_510) || (SCX6300_6400S) || (SPR800) \
-	|| (SC65_66S)   || (SC85_86S)
-  sepip->qlevel = PIPS_LV_STD360;
 #else
-  sepip->qlevel = PIPS_LV_STD;
+	sepip->qlevel = PIPS_LV_STD;
 #endif
 	
 #ifdef CONV_VERSION2
@@ -1068,9 +1018,6 @@ defSet (SEP_INIT_PARAM *sepip)
 	sepip->multi_page = PIPS_MP_1;
 	sepip->auto_cut = PIPS_CP_NONE;
 	sepip->inkset = get_inkset();
-	
-	/* 2004.01.21 */
-	sepip->clear_ink =PIPS_CI_OFF;
 
 	checkConf(sepip);
 }
@@ -1132,10 +1079,7 @@ valueCheck (int id, char sub[SUB_MAX][ARRAY_MAX])
 	{
 /* 	case P_MEDIA_SIZE: entry = mediaSizeEntry; break; */
 	case P_BIN: entry = binEntry; break;
-#if AUTO_CUT
-	/* 2004.03.05 for Auto Cut */
 	case P_AUTO_CUT: entry = autoCutEntry; break;
-#endif
 	case P_INK: entry = inkEntry; break;
 	case P_RESOLUTION: entry = resolutionEntry; break;
 	case P_MEDIA_TYPE: entry = mediaTypeEntry; break;
@@ -1143,11 +1087,6 @@ valueCheck (int id, char sub[SUB_MAX][ARRAY_MAX])
 	case P_HALF_TONE: entry = halftoneEntry; break;
 	case P_QUALITY_LEVEL: entry = levelEntry; break;
 	case P_MULTI_PAGE: entry = multiPageEntry; break;
-
-#if CLEAR_INK
-	/* 2004.01.24 for Clear Ink */
-	case P_CLEAR_INK: entry = clearInkEntry; break; 		
-#endif
 	case P_MICRO_WEAVE:
 	case P_HIGH_SPEED:
 	case P_FIT_PAGE:
@@ -1234,18 +1173,8 @@ check_peculiar_to_model (const short *mode, int count,
 #elif SP830U
 		de_mode_list = de_param_mode_t4_for_sp830u;
 		
-#elif (PM4000PX) || (SP2100_2200) || (PM3700C) || (PM940C) || (PMG700) || (SC64_63S) \
-   || (PXV600)   || (CC600PX)     || (PMA850)  || (PMD750) || (SC84_83S) || (SCX5300_5400S) \
-   || (SPR300_310) || (SPR200_210) || (SPRX600_610) || (SPRX500_510) || (SCX6300_6400S) \
-   || (PXV500)   || (SC65_66S)    || (SC85_86S)
-
-#if  (SC64_63S)  || (SC84_83S) || (SCX6300_6400S) || (SC65_66S) || (SC85_86S)
-		de_mode_list = ( sepip->prt_format == PIPS_OUTPUT_MONO ) ?
-				de_param_mode_t4_mono : de_param_mode_t4;
-#else
+#elif (PM4000PX) || (SP2100_2200) || (PM3700C) || (PM940C)
 		de_mode_list = de_param_mode_t4;
-#endif
-
 #else 
 		short default_list[] = {-1};		
 		de_mode_list = default_list;
