@@ -39,17 +39,13 @@
  || (PM730C)      || (PM830C)   || (PM890C)   || (PM950C)    || (PM850PT) \
  || (PM840C)      || (SP960)    || (SP925)    || (PM740C)    || (PM740DU) \
  || (PM870C)      || (PM860PT)  || (PM930C)   || (PXV700)    || (SP830U) \
- || (SP2100_2200) || (PM4000PX) || (PM3700C)  || (PM940C)    || (PM980C) || (PMG700) \
- || (PXG900)   \
- || (SC64_63S)    || (PXV600)   || (PMG800)   || (CC600PX)   || (PMA850) || (PMD750) \
- || (SC84_83S)    || (SCX5300_5400S) || (SPR300_310) || (SPR200_210) || (SPRX600_610)\
- || (SPRX500_510) || (SCX6300_6400S) || (PXV500) || (SPR800) || (SC65_66S) || (SC85_86S)
+ || (SP2100_2200) || (PM4000PX) || (PM3700C)  || (PM940C)    || (PM980C)    
 #define USE_AUTO_TRIM_4
 #endif
 
 /* ϲ240dpiѤ뵡 */
-#if (SC580) || (SC480) || (SC40S) || (SC20S) || (SC41_42S) || (SC43S) || (SC45_46S)
-#define USE_RESOLUTION_240 1
+#if (SC580) || (SC480) || (SC40S) || (SC20S) || (SC41_42S) || (SC43S)
+#define USE_RESOLUTION_240
 #endif
 
 /* ȥåȤɸƤ뵡 */
@@ -63,22 +59,20 @@
 #endif
 
 /* ɥեȰβ٤360dpiǤ뵡 */
-#if (PM950C) || (SP960) || (SP2100_2200) || (PM4000PX) || (PM980C) || (PMG800) || (PXG900) \
- || (SPR800)
+#if (PM950C) || (SP960) || (SP2100_2200) || (PM4000PX) || (PM980C)
 #define USE_360_DRAFT
 #endif
 
 /* ɥեȰβ٤180dpiǤ뵡 */
 #if (PM760C) || (PM750_2000C) || (PM2200C) || (PM900C) || (PM670C) \
  || (SC980)  || (PM920C)      || (SC70S)   || (SC80S)  || (SC82S) \
- || (PXV700) || (PM940C)      || (PXV600)  || (CC600PX)|| (SC84_83S) \
- || (SCX5100_5200S) || (SCX5300_5400S) || (SCX6300_6400S) || (SC85_86S)
+ || (PXV700) || (PM940C)
 #define USE_180_DRAFT
 #endif
 
 /* Υ󥯤ѤƤ뵡 */
 #if (SC70S)       || (SC80S) || (PM950C) || (SP960) || (PXV700) \
- || (SP2100_2200) || (PM4000PX)
+ || (SP2100_2200) || (PM4000PX) 
 #define USE_INKBOX
 #endif
 
@@ -87,13 +81,7 @@
 #ifdef INK_CHANGE_SYSTEM
 #define MODE_ITEM 7
 #else
-
-#if CLEAR_INK
-#define MODE_ITEM 7
-#else
 #define MODE_ITEM 6
-#endif /* CLEAR_INK */
-
 #endif /* INK_CHANGE_SYSTEM */
 
 
@@ -107,15 +95,7 @@ enum MODE_OFSET
 #ifdef INK_CHANGE_SYSTEM
 	MOFS_INKSET,
 #endif /* INK_CHANGE_SYSTEM */
-#if CLEAR_INK
-	/* 2004.01.24 Clear Ink */
-	/* CLEAR_INK is 1 or 0  */
-	MOFS_QUALITY,
-	MOFS_CLEAR_INK
-#else
- 	MOFS_QUALITY
-#endif
-	
+	MOFS_QUALITY
 };
 
 /* output type */
@@ -134,10 +114,7 @@ enum eINKSET
   PIPS_INKSET_CMYKcmDY,
   PIPS_INKSET_CMYKcmLk,
   PIPS_INKSET_CMYcmMkLk,
-  PIPS_INKSET_CMYcmMk,
-  PIPS_INKSET_CMYKRVCl,		/* 2004.01.22 New Ink */
-  PIPS_INKSET_CMYKRV		/* 2004.01.22 New Ink */  
-  
+  PIPS_INKSET_CMYcmMk
 };
 
 /* media size */
@@ -177,11 +154,7 @@ enum ePAPER_SIZE
   PIPS_PAPER_PHOTO_100x150,
   PIPS_PAPER_PHOTO_200x300,
   PIPS_PAPER_4X6FULL,
-  PIPS_PAPER_PANORAMIC,
-
-  PIPS_PAPER_CREDITCARD,
-  PIPS_PAPER_BUSINESS_CARD,
-
+  PIPS_PAPER_PANORAMIC
 };
 
 
@@ -215,28 +188,7 @@ enum eMEDIA_TYPE
   PIPS_MED_GLOSSYPHOTOPAPER,
   PIPS_MED_MCLP,
   PIPS_MED_WATERCOLOR,
-  PIPS_MED_ERC,
-
-  PIPS_MED_EPM,
-  PIPS_MED_EDMP,
-  PIPS_MED_EPS,
-  PIPS_MED_EIRON_PRINT,
-
-  PIPS_MED_EPP_P,
-  PIPS_MED_BWP,
-
-  PIPS_MED_RPPC,
-  PIPS_MED_ERC_S,
-  PIPS_MED_EGPP,
-
-  PIPS_MED_EOHP,              
-  PIPS_MED_P_BOARD,     
-
-  PIPS_MED_ADDRESSSIDE,
-  PIPS_MED_SF_POSTCARD,
- 
-  PIPS_MED_PLAIN_SPEED,	// special media.
-  PIPS_MED_PLAIN_BKSAVE // special media. Black Ink Save Mode 2004.3.231 add
+  PIPS_MED_ERC
  
 };
 
@@ -285,15 +237,13 @@ enum eFEEDER
   PIPS_BIN_TRIMBANNER,
   PIPS_BIN_AUTO_TRIM,
   PIPS_BIN_AUTO_TRIM_4,
-  PIPS_BIN_AUTO_EX, 
-  PIPS_BIN_MANUAL,       
-  PIPS_BIN_MANUAL_TRIM
+  PIPS_BIN_AUTO_EX
 };
 
 /* quality level set pattern bits */
 enum eQUALITY
 {
-#if (HIGH_RESOLUTION == 0)
+#if (!HIGH_RESOLUTION)
 
 #ifdef USE_360_DRAFT
   PIPS_LV_DRAFT = 10,
@@ -307,7 +257,7 @@ enum eQUALITY
   PIPS_LV_PHOTO,
   PIPS_LV_SPHOTO,
 
-#elif(HIGH_RESOLUTION == 1)
+#else
 
 /*   */
 #ifdef USE_360_DRAFT
@@ -323,23 +273,6 @@ enum eQUALITY
   PIPS_LV_PHOTO2880,
   PIPS_LV_SPHOTO2880,
 
-#else
-
-/* 2  */
-#ifdef USE_360_DRAFT
-  PIPS_LV_DRAFT = 10,
-  PIPS_LV_STD360 = 1,
-#else
-  PIPS_LV_DRAFT = 0,
-  PIPS_LV_STD360,
-#endif /* USE_360_DRAFT */
-  PIPS_LV_FINE720,
-  PIPS_LV_SFINE720,
-  PIPS_LV_PHOTO1440,
-  PIPS_LV_PHOTO2880,
-  PIPS_LV_SPHOTO1440,
-  PIPS_LV_SPHOTO2880,
-
 #endif
   
 /* 2003.05 Added */
@@ -378,16 +311,6 @@ enum eAUTO_CUT
 	PIPS_CP_2
 };
 
-/* Clear ink */
-/* bit operation */
-enum eCLEAR_INK
-{
-	PIPS_CI_OFF  = 1,       /* bit 0 */
-	PIPS_CI_ON   = 2,	/* bit 1 */
-	PIPS_CI_AUTO = 4,	/* bit 2 */
-        PIPS_CI_FULL = 8	/* bit 3 */
-};
-
 
 #ifndef __PIPS_DEF_H__
 typedef unsigned int UINT;
