@@ -165,7 +165,7 @@ commonSetOptionsSensitive (void)
 	}
   
   
-	if (strcmp ((char *)options[P_COLOR_MODE], "NONE") || !flag[0] ) flag[1] = TRUE;
+	if (strcmp ((char *)options[P_COLOR_MODE], "NONE")) flag[1] = TRUE;
 	else flag[1] = FALSE;
 	adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_BRIGHTNESS], flag[1]);
 	adjustmentPackSetSensitive ((ADJUSTMENT_PACK *)opt_address[P_CONTRAST], flag[1]);
@@ -186,12 +186,11 @@ commonSetOptionsSensitive (void)
 	}
 
 
-	/* ѥ᡼,Υߡ 	*/
-	/* 2004.01.26 Added clear_ink	*/ 
+	/* ѥ᡼,Υߡ */
 	sepip_lite->src_resolution.x = sepip_lite->halftone_type
 		= sepip_lite->high_speed = sepip_lite->qlevel
 		= sepip_lite->media_type = sepip_lite->mw_type
-		= sepip_lite->bin_id = sepip_lite->inkset = sepip_lite->clear_ink = -1;
+		= sepip_lite->bin_id = sepip_lite->inkset = -1;
 
 	/* make new media type entry */
 #if defined(USE_AUTO_TRIM_4) || defined(INK_CHANGE_SYSTEM)
@@ -394,29 +393,6 @@ commonSetOptionsSensitive (void)
 	new_entry[count] = NULL;
 	selectPackSetSensitive ((SELECT_PACK *)opt_address[P_HALF_TONE], new_entry);
   
-#if CLEAR_INK
-	/* 2004.01.26 Clear Ink Entry */
-	data = opt_all[P_CLEAR_INK].data;
-	for (i = 0; data[i].value != END_ARRAY; i++) flag[i] = FALSE;
-	for (i = 0; mode[i * MODE_ITEM] >= 0; i++)
-	{
-		if (!printModeCheck(mode, i, sepip_lite))
-		{
-			for (j = 0; data[j].value != END_ARRAY; j++)
-			{
-				offset = i * MODE_ITEM;
-				if (mode[offset + MOFS_CLEAR_INK] & data[j].value ) flag[j] = TRUE;
-			}
-			break;
-		}
-	}
-	count = 0;
-	for (i = 0; data[i].value != END_ARRAY; i++)
-		if (flag[i] == TRUE)
-			new_entry[count++] = data[i].rsc_name;
-	new_entry[count] = NULL;
-	selectPackSetSensitive ((SELECT_PACK *)opt_address[P_CLEAR_INK], new_entry);
-#endif
 
 	bin_type = getValueOfDatabases (P_BIN, (char *)options[P_BIN]);
 
@@ -440,10 +416,6 @@ commonSetOptionsSensitive (void)
 #ifdef USE_AUTO_TRIM_4
 		case PIPS_BIN_AUTO_TRIM_4: msentry = mediaSizeEntry_NMA; break;
 #endif
-#if (PMG800) || (PXG900)
-		case PIPS_BIN_MANUAL: msentry = mediaSizeEntry_M; break;
-		case PIPS_BIN_MANUAL_TRIM: msentry = mediaSizeEntry_TM; break;
-#endif
 
 		default: abort ();
 		}
@@ -486,7 +458,6 @@ commonSetOptionsSensitive (void)
 #endif
 	}
 
-#if AUTO_CUT
 	/* Auto cut */
 	{
 		data = opt_all[P_AUTO_CUT].data;
@@ -516,7 +487,7 @@ commonSetOptionsSensitive (void)
 		}
 		selectPackSetSensitive ((SELECT_PACK *)opt_address[P_AUTO_CUT], new_entry);
 	}
-#endif
+
 
 	free (sepip_lite);
 
@@ -1726,6 +1697,7 @@ ink_list_delete (InkList list)
 static void
 setInkboxProg (char *buffer)
 {
+	GtkWidget *pix;
 	GdkPixmap *inkbox_pixmap;
 	GdkBitmap *inkbox_mask;
 	int inkset;
@@ -1815,12 +1787,7 @@ commandButtonClicked (GtkWidget *widget, char* text)
 		0x1b, 0x28, 0x52, 0x08, 0x00, 0x00, 0x52, 0x45,
 		0x4d, 0x4f, 0x54, 0x45, 0x31,
 
-#if PMG800 || PXG900 || SPR800
-		'P', 'P', 0x03, 0x00, 0x00, 0x01,0xff,
-		'N', 'C', 0x02, 0x00, 0x00, 0x10,
-#else
 		'N', 'C', 0x02, 0x00, 0x00, 0x00,
-#endif
 
 		0x1b, 0x00, 0x00, 0x00,
 		0x0d, 0x0a, 0x0d, 0x0a,
@@ -1907,7 +1874,7 @@ commandButtonClicked (GtkWidget *widget, char* text)
 #elif (PM900C) || (PM920C)
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 2 --patch 1 --platen", prt_command);
 #elif (SC40S) || (SC20S) || (SP810_820) || (PM730C) || (SC60S) || (SC41_42S) \
-   || (SC61_62S) || (PM740C) || (PM740DU) || (CL760) || (SC43S) || (SP830U) || (SC45_46S)
+   || (SC61_62S) || (PM740C) || (PM740DU) || (CL760) || (SC43S) || (SP830U)
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 3 --rpath " RULED_PATH , prt_command);
 #elif (SC980)
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 2", prt_command);
@@ -1916,13 +1883,9 @@ commandButtonClicked (GtkWidget *widget, char* text)
 #elif (SC70S) || (SC80S)
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 4 --band 1 --bpath " BAND_PATH , prt_command);
 #elif (PM890C) || (PM950C) || (PM850PT) || (PM840C) || (SP960) || (SP925) \
-   || (PM870C) || (PM930C) || (PM860PT) || (SP2100_2200) || (PM4000PX) \
-   || (PM939C) || (PMG700) || (PMG800)  || (PMA850) || (PMD750) || (PXG900) \
-   || (SPR300_310) || (SPR200_210) || (SPRX600_610) || (SPRX500_510) || (SPR800)
+   || (PM870C) || (PM930C) || (PM860PT) || (SP2100_2200) || (PM4000PX) || (PM940C)
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --extension \"%s\" --ppath " PATCH_PATH , prt_command, PRINTER_MODEL);
-#elif  (SC64_63S) || (PXV600) || (SC84_83S) || (PXV500) || (SC65_66S) || (SC85_86S)
-				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --extension \"%s\" --ppath " PATCH_PATH " --bpath " BAND_PATH, prt_command, PRINTER_MODEL);
-#elif  (SC82S) || (PXV700) || (CC600PX) || (SCX5100_5200S) || (SCX5300_5400S) || (SCX6300_6400S)
+#elif  (SC82S) || (PXV700)
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --extension \"%s\" --rpath " RULED_PATH " --bpath " BAND_PATH , prt_command, PRINTER_MODEL);
 #elif  (PM970C) || (PM980C)
  				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --extension \"%s\" --rpath " RULED_PATH " --ppath " PATCH_PATH , prt_command, PRINTER_MODEL);
@@ -1932,15 +1895,13 @@ commandButtonClicked (GtkWidget *widget, char* text)
 			}
 			else if (!strcmp (text, _(Ink_Chenge)))
 				sprintf (navi_command, NAVI_PATH " --ink");
-#if AUTO_CUT
+
 			else if (!strcmp (text, _(Auto_Cutter_Adjustment)))
 				sprintf (navi_command, NAVI_PATH " --cut --printer \"%s\" --extension \"%s\" --cpath " CUT_PATH, prt_command, PRINTER_MODEL);
-#endif
 /*
 			fprintf (stderr, "Debug : navi_command : %s\n", navi_command); 
 */
 			strcat (navi_command, " 2> /dev/null");
-//			strcat (navi_command, " 2> /tmp/navi.dmp");
 			system (navi_command);
 		}
 	}
